import React, { useState, useEffect } from 'react';
import {
  InputNumber,
  Row,
  Col,
  Switch,
  Checkbox,
  Space,
  Steps,
  message,
  Modal,
  Form,
  Input,
  Button,
  Select,
  DatePicker,
  Upload
} from 'antd';
import { MinusCircleOutlined, PlusOutlined, UploadOutlined } from '@ant-design/icons';

import api from '../services';
const RobotActions = (props) => {

  const { Option, OptGroup } = Select;
  const [options, setoptions] = useState();
  //每次触发
  useEffect(() => {
    const initoptions = async (value) => {
      var data = await api.getStirFryArray("sirfryrobotaction");
      if (data != undefined) {
        setoptions(data.data);
      }
    };
    initoptions();
  }, []);


  return (
    <Modal
      title={'机械臂配置'}
      width={500}
      visible={props.createModalVisible}
      //visible={options11}
      footer={null} //底部内容
      onCancel={() => {
        props.onCancel();
      }}
      //关闭时销毁 Modal 里的子元素
      destroyOnClose={true}
    >
      <Form
        preserve={false}
        form={props.form}
        labelCol={{ span: 4 }}
        layout="Horizontal"
        onFinish={props.onFinish}
        initialValues={props.values}
      >
        <span >
          <Form.Item name="id" hidden={true}>
            <Input />
          </Form.Item>
          <Form.Item
            noStyle
            shouldUpdate={(prevValues, currentValues) =>
              prevValues.activityType !== currentValues.activityType
            }  >
            {({ getFieldValue }) =>
              (<Form.Item>

                  <Form.List name="robotActions">
                    {(fields, { add, remove }) => (
                      <>
                        {fields?.map(({ key, name, fieldKey, ...restField },index) => (
                          <Space
                            key={index}
                            style={{ display: 'flex', marginBottom: 8 }}
                            align="baseline"
                          >
                            <Form.Item
                              {...restField}
                              label={"机械臂动作"}

                              name={[name, 'value']}
                              fieldKey={[fieldKey, 'value']}
                              rules={[{ required: true, message: '请选择' }]} >
                              {
                               <Select style={{ width: 200 }}
                                    showSearch
                                    optionFilterProp="children"
                                    filterOption={(input, option) =>
                                      option.children.toLowerCase().indexOf(input.toLowerCase()) >= 0
                                    } >
                                    {options?.map((item, index) => {
                                      return (
                                        <Option
                                          index={item}
                                          value={item}
                                          key={index}
                                        >
                                          {item}
                                        </Option>
                                      );
                                    })}
                                  </Select>
                              }

                            </Form.Item>
                            <MinusCircleOutlined onClick={() => remove(name)} />
                          </Space >
                        ))
                        }
                        <Form.Item>
                          <Button type="dashed" onClick={() => add()} block icon={<PlusOutlined />}>
                            添加
                          </Button>
                        </Form.Item>
                      </>
                    )}
                  </Form.List >
                </Form.Item >

              )
            }
          </Form.Item >

          <Form.Item>
            <Button type="primary" htmlType="submit" style={{ float: 'right' }}>
              保存
            </Button>
          </Form.Item>
        </span >
      </Form >
    </Modal >
  );
};

export default RobotActions;
