import { DropboxOutlined, PlusOutlined } from '@ant-design/icons';
import { Button, message, Input, Drawer, Modal, Popconfirm } from 'antd';
import React, { useState, useRef, useEffect } from 'react';
import { PageContainer, FooterToolbar } from '@ant-design/pro-layout';
import ProTable from '@ant-design/pro-table';
import ProDescriptions from '@ant-design/pro-descriptions';
import CreateForm from './components/CreateForm';
import {
  producttypeList,
  addproducttype,
  updateproducttype,
  removeproducttype,
  removeSingleproducttype,
  GetDicList,
  IsModifyOrDel
} from './services';

//页面 相当于 class
/**
 * 添加节点
 *
 * @param fields
 */
const handleAdd = async (fields) => {
  try {
    await addproducttype(JSON.stringify(fields)).then((r) => {
      if (r.data) {
        message.success('添加成功');
      } else {
        message.error('添加失败请重试！');
      }
    });
    return true;
  } catch (error) {
    message.error('添加失败请重试！');
    return false;
  }
}
/**
   * 批量删除节点
   *
   * @param selectedRows
   */
const handleRemove = async (selectedRows) => {
  if (!selectedRows) return true;
  try {
    var strText = '';
    await IsModifyOrDel(selectedRows.map((row) => row.id), " ", "1").then((r) => {
      var data = r.data;
      data.forEach((x) => {
        strText = x.itemName;
      });
      if (strText != '') {
        message.error('物料类型名称【' + strText.substring(0, strText.lastIndexOf('、')) + '】下存在物料信息不能删除,请重新选择！');
      } else {
        removeproducttype(selectedRowsState.map((row) => row.id)).then((r) => {
          if (r.data) {
            message.success('删除成功，即将刷新');
          } else {
            message.error('删除失败，请重试');
          }
        });
      }
    });
    return true;
  } catch (error) {
    message.error('删除失败，请重试');
  }
}

/**
 * 更新节点
 *
 * @param fields
 */

const handleUpdate = async (fields) => {
  try {
    var strText = null;
    await IsModifyOrDel(fields.id, fields.status, "1").then((r) => {
      var data = r.data;
      data.forEach((x) => {
        strText = x.itemName;
      });
      if (strText != null) {
        message.error('类型名称【' + strText.substring(0, strText.lastIndexOf('、')) + '】下存在物料信息不能修改状态');
      } else {
        updateproducttype(fields).then((r) => {
          if (r.data) {
            message.success('修改成功');
          } else {
            message.error('修改失败请重试！');
          }
        });
      }
    });
    return true;
  } catch (error) {
    message.error('修改失败请重试！');
    return false;
  }
}
//页面 相当于 class
const FranchiessSrdTypeManage = () => {
  /** 新建/更新窗口的弹窗 */
  const [createModalVisible, handleModalVisible] = useState(false);
  /** 分布更新窗口的弹窗 */

  const [showDetail, setShowDetail] = useState(false);
  //绑定
  const actionRef = useRef();
  const [currentRow, setCurrentRow] = useState();
  //选中的行
  const [selectedRowsState, setSelectedRows] = useState([]);

  /** 国际化配置 */

  const columns = [
    {
      title: '主键',
      dataIndex: 'id',
      tip: '规则名称是唯一的 key',
      hideInSearch: true,
      hideInTable: true,
      render: (dom, entity) => {
        return (
          <a
            onClick={() => {
              setCurrentRow(entity);
              setShowDetail(true);
            }}
          >
            {dom}
          </a>
        );
      },
    },
    {
      title: '名称',
      dataIndex: 'name',
      valueType: 'textarea',
      ellipsis: true,
    },

    {
      title: '状态',
      dataIndex: 'status',
      hideInForm: true,
      valueEnum: {
        0: {
          text: '正常',
          status: 'Processing',
        },
        1: {
          text: '停用',
          status: 'Success',
        },
      },
    },
    {
      title: '创建时间',
      dataIndex: 'createAt',
      valueType: 'date',
      hideInSearch:true,
    },
    {
      title: '操作',
      dataIndex: 'option',
      valueType: 'option',
      render: (_, record) => [
        <a
          key="config"
          onClick={() => {
            handleModalVisible(true);
            setCurrentRow(record);
          }}
        >
          更新
        </a>,
        <Popconfirm
          type="primary"
          key="primary"
          title="确认删除吗？"
          okText="是"
          cancelText="否"
          onConfirm={() => {

            var msgText = '';
            IsModifyOrDel(record.id, ' ', "1").then((r) => {
              var data = r.data;
              data.forEach((x) => {
                msgText = x.itemName;
              })
              if (msgText != '') {
                message.error('类型名称【' + msgText.substring(0, msgText.lastIndexOf('、')) + '】下存在物料信息不能删除,请重新选择！');
              } else {
                removeproducttype([record.id]).then((r) => {
                  if (r.data) {
                    message.success('删除成功，即将刷新');
                    actionRef.current.reload();
                  } else {
                    message.error('删除失败，请重试');
                  }
                });
              }
            });

          }}
          onCancel={() => { }}
        >
          <a href="#">删除</a>
        </Popconfirm>,
      ],
    },
  ];

  return (
    <PageContainer>
      <ProTable
        headerTitle="物料分类"
        actionRef={actionRef}
        rowKey="id"
        search={{
          labelWidth: 120,
        }}
        columns={columns}
        toolBarRender={() => [
          <Button
            type="primary"
            key="primary"
            onClick={() => {
              handleModalVisible(true);
              setCurrentRow({});
            }}
          >
            <PlusOutlined /> 新建
          </Button>,
        ]}
        //数据绑定
        request={async (params) => {
          console.log("fsa","gfdsgfd");
          var franchiessSrdtypeData = [];
          var total = 0;
          await producttypeList(params).then((r) => {
            franchiessSrdtypeData = r.data.data;
            franchiessSrdtypeData.forEach((x) => {
              x.status = x.status.toString();
            });
            total = r.data.total;
          });
          return {
            data: franchiessSrdtypeData,
            success: true,
            total: total,
          };
        }}
        // 每行选择点击事件
        rowSelection={{
          onChange: (_, selectedRows) => {
            setSelectedRows(selectedRows);
          },
        }}
      ></ProTable>
      {selectedRowsState?.length > 0 && (
        <FooterToolbar
          extra={
            <div>
              已选择{' '}
              <a
                style={{
                  fontWeight: 600,
                }}
              >
                {selectedRowsState.length}
              </a>{' '}
              项 &nbsp;&nbsp;
            </div>
          }
        >
          {/* <Button
            onClick={() => {
              handleRemove(selectedRowsState);
              setSelectedRows([]);
              actionRef.current?.reloadAndRest?.();
            }}
            type="primary"
            key="primary"
          >
            批量删除
          </Button> */}
        </FooterToolbar>
      )}
      {/* 加盟商管理(新增，修改) */}
      <CreateForm
        onFinish={async (value) => {
          var success = false;
          if (value.id) {
            success = await handleUpdate(value);
          } else {
            success = await handleAdd(value);
          }
          if (success) {
            handleModalVisible(false);
            if (actionRef.current) {
              actionRef.current.reload();
            }
          }
        }}
        onCancel={() => {
          setCurrentRow(undefined);
          handleModalVisible(false);
        }}
        createModalVisible={createModalVisible}
        values={currentRow || {}}
      />
      <Drawer
        width={600}
        visible={showDetail}
        onClose={() => {
          setCurrentRow(undefined);
          setShowDetail(false);
        }}
        closable={false}
      >
        {currentRow?.name && (
          <ProDescriptions
            column={2}
            title={currentRow?.name}
            request={async () => ({
              data: currentRow || {},
            })}
            params={{
              id: currentRow?.name,
            }}
            columns={columns}
          />
        )}
      </Drawer>
    </PageContainer>
  );
};

export default FranchiessSrdTypeManage;
