import { DropboxOutlined, PlusOutlined } from '@ant-design/icons';
import { Button, message, Input, Drawer, Modal, Popconfirm } from 'antd';
import React, { useState, useRef } from 'react';
import { PageContainer, FooterToolbar } from '@ant-design/pro-layout';
import ProTable from '@ant-design/pro-table';
import ProDescriptions from '@ant-design/pro-descriptions';
import CreateForm from './components/CreateForm';
import moment from 'moment';
import { getPlanList, addPlan, updatePlan, removePlan } from './services';

//页面 相当于 class
const PlanManage = () => {
  /** 新建/更新窗口的弹窗 */
  const [createModalVisible, handleModalVisible] = useState(false);
  /** 分布更新窗口的弹窗 */

  const [showDetail, setShowDetail] = useState(false);
  //绑定
  const actionRef = useRef();
  const [currentRow, setCurrentRow] = useState();

  //选中的行
  const [selectedRowsState, setSelectedRows] = useState([]);

  /**
   * 添加节点
   *
   * @param fields
   */
  function handleAdd(fields) {
    // message.loading('正在添加');
    try {

      addPlan(JSON.stringify(fields));
      message.success('添加成功');
      //刷新数据
      actionRef.current.reload();
      return true;
    } catch (error) {
      message.error('添加失败请重试！');
      return false;
    }
  }

  /**
   * 更新节点
   *
   * @param fields
   */

  function handleUpdate(fields) {
    try {
      updatePlan(JSON.stringify(fields)).then((r) => {
        if (r.data) {
          message.success('修改成功');
          actionRef.current.reload();
        } else {
          message.error('修改失败请重试！');
        }
      });
      return true;
    } catch (error) {
      message.error('修改失败请重试！');
      return false;
    }
  }

  /**
   * 批量删除节点
   *
   * @param selectedRows
   */
  function handleRemove() {
    try {
      removePlan(selectedRowsState.map((item, index) => item.id)).then((r) => {
        if (r.data) {
          message.success('删除成功，即将刷新');
        } else {
          message.error('删除失败，请重试');
        }
      });
      //刷新数据
      actionRef.current.reload();
      return true;
    } catch (error) {
      message.error('删除失败，请重试');
    }
  }
  /**
   * 删除单条数据
   *
   * @param selectedRows
   */
  function handleRemoveSingle(value) {
    try {
      removeSingleAccount(value).then((r) => {
        if (r.data) {
          message.success('删除成功，即将刷新');
          //刷新数据
          actionRef.current.reload();
        } else {
          message.error('删除失败，请重试');
        }
      });
      return true;
    } catch (error) {
      message.error('删除失败，请重试');
    }
  }

  /** 国际化配置 */

  const columns = [
    {
      title: '主键',
      dataIndex: 'id',
      tip: '规则名称是唯一的 key',
      hideInSearch: true,
      hideInTable: true,
      render: (dom, entity) => {
        return (
          <a
            onClick={() => {
              setCurrentRow(entity);
              setShowDetail(true);
            }}
          >
            {dom}
          </a>
        );
      },
    },
    {
      title: '分账方案名称',
      dataIndex: 'planName',
      valueType: 'textarea',
    },
    {
      title: '开始时间',
      hideInSearch: true,
      dataIndex: 'planStartTime',
      valueType: 'dateTime',
    },
    {
      title: '结束时间',
      hideInSearch: true,
      dataIndex: 'planEndTime',
      valueType: 'dateTime',
    },
    {
      title: '服务费比例',
      dataIndex: 'serviceFee',
      valueType: 'textarea',
      hideInSearch: true,
    },
    {
      title: '备注',
      dataIndex: 'remark',
      valueType: 'textarea',
      hideInSearch: true,
    },
    {
      title: '创建时间',
      dataIndex: 'createAt',
      valueType: 'textarea',
      hideInSearch: true,
    },
    {
      title: '操作',
      dataIndex: 'option',
      valueType: 'option',
      render: (_, record) => [
        <a
          key="config"
          onClick={() => {
            handleModalVisible(true);
            setCurrentRow(() => {
              if (record.planStartTime != null) {
                record.planStartTime = moment(record.planStartTime);
                record.planEndTime = moment(record.planEndTime);
              }
              return record;
            });
          }}
        >
          更新
        </a>,
        // <Popconfirm
        //     type="primary"
        //     key="primary"
        //     title="确认删除吗？"
        //     okText="是"
        //     cancelText="否"
        //     onConfirm={() => {
        //         handleRemoveSingle(record.id);
        //     }}
        //     onCancel={() => { }}
        // >
        //     <a href="#">删除</a>
        // </Popconfirm>,
      ],
    },
  ];

  return (
    <PageContainer>
      <ProTable
        headerTitle="分账方案"
        actionRef={actionRef}
        rowKey="id"
        search={{
          labelWidth: 120,
        }}
        columns={columns}
        toolBarRender={() => [
          <Button
            type="primary"
            key="primary"
            onClick={() => {
              handleModalVisible(true);
              setCurrentRow({});
            }}
          >
            <PlusOutlined /> 新建
          </Button>,
        ]}
        //数据绑定
        request={async (params) => {
          var franchiessSrdtypeData = [];
          var total = 0;
          await getPlanList(params).then((r) => {
            franchiessSrdtypeData = r.data.data;
            total = r.data.total;
          });
          return {
            data: franchiessSrdtypeData,
            success: true,
            total: total,
          };
        }}
        // 每行选择点击事件
        rowSelection={{
          onChange: (_, selectedRows) => {
            setSelectedRows(selectedRows);
          },
        }}
      ></ProTable>
      {selectedRowsState?.length > 0 && (
        <FooterToolbar
          extra={
            <div>
              已选择{' '}
              <a
                style={{
                  fontWeight: 600,
                }}
              >
                {selectedRowsState.length}
              </a>{' '}
              项 &nbsp;&nbsp;
            </div>
          }
        >
          {/* <Button
            onClick={() => {
              handleRemove(selectedRowsState);
              setSelectedRows([]);
              actionRef.current?.reloadAndRest?.();
            }}
            type="primary"
            key="primary"
          >
            批量删除
          </Button> */}

          <Popconfirm
            type="primary"
            key="primary"
            title="确认是否删除选中项？"
            okText="是"
            cancelText="否"
            onConfirm={() => {
              handleRemove(selectedRowsState);
              setSelectedRows([]);
              actionRef.current?.reloadAndRest?.();
            }}
            onCancel={() => { }}
          >
            <a href="#">批量删除</a>
          </Popconfirm>

        </FooterToolbar>
      )}
      {/* 分账方案管理(新增，修改) */}
      <CreateForm
        onFinish={async (value) => {
          var success = false;
          value.planStartTime = new Date(value.planDate[0]);
          value.planEndTime = new Date(value.planDate[1]);

          if (value.id) {
            success = await handleUpdate(value);
          } else {
            success = await handleAdd(value);
          }
          if (success) {
            handleModalVisible(false);
            if (actionRef.current) {
              actionRef.current.reload();
            }
          }
        }}

        onCancel={() => {
          setCurrentRow(undefined);
          handleModalVisible(false);
        }}

        createModalVisible={createModalVisible}
        values={currentRow || {}}
      />
      <Drawer
        width={600}
        visible={showDetail}
        onClose={() => {
          setCurrentRow(undefined);
          setShowDetail(false);
        }}
        closable={false}
      >
        {currentRow?.name && (
          <ProDescriptions
            column={2}
            title={currentRow?.name}
            request={async () => ({
              data: currentRow || {},
            })}
            params={{
              id: currentRow?.name,
            }}
            columns={columns}
          />
        )}
      </Drawer>
    </PageContainer>
  );
};

export default PlanManage;
