import { PlusOutlined } from '@ant-design/icons';
import { Button, message, Select } from 'antd';
import React, { useState, useRef } from 'react';
import { PageContainer, FooterToolbar } from '@ant-design/pro-layout';
import ProTable from '@ant-design/pro-table';
import CreateForm from './components/CreateForm'
import PwdForm from './components/PwdForm'
import RoleForm from './components/RoleAuth'
import OrgForm from './components/OrgForm';
import api from './service';
import Enumerable from 'linq';
/**
 * 添加节点
 *
 * @param fields
 */

const handleAdd = async (fields) => {
  try {
    await api.Add(fields).then((r) => {
      if (r.data) {
        message.success('添加成功');
      } else {
        message.error('添加失败请重试！');
      }
    });
    return true;
  } catch (error) {
    message.error('添加失败请重试！');
    return false;
  }
};
/**
 * 正在分配数据权限
 * @param fields
 */
const handleGrantData = async (fields) => {
  const hide = message.loading('正在分配数据权限');
  try {
    await api.SetDataRole({ ...fields });
    hide();
    message.success('分配数据权限成功');
    return true;
  } catch (error) {
    hide();
    message.error('分配数据权限失败请重试！');
    return false;
  }
};
/**
 * 更新节点
 *
 * @param fields
 */

const handleUpdate = async (fields) => {
  try {
    await api.Update(fields).then((r) => {
      if (r.data) {
        message.success('修改成功');
      } else {
        message.error('修改失败请重试！');
      }
    });
    return true;
  } catch (error) {
    message.error('修改失败请重试!');
    return false;
  }
};
/**
 * 删除节点
 *
 * @param selectedRows
 */

const handleRemove = async (selectedRows) => {
  if (!selectedRows) return true;
  try {
    await api.RemoveUser(selectedRows.map((row) => row.id)).then((r) => {
      if (r.data) {
        message.success('删除成功，即将刷新');
        return true;
      } else {
        message.error('删除失败，请重试');
      }
    });
    return true;
  } catch (error) {
    message.error('删除失败，请重试');
    return false;
  }
};
const Prefix = "User";
const userManager = () => {
  /** 新建窗口的弹窗 */
  const [createModalVisible, handleModalVisible] = useState();
  const [stepFormValues, setStepFormValues] = useState({});
  const [updateOrgModalVisible, handleUpdateOrgModalVisible] = useState();
  /*绑定数据 */
  const actionRef = useRef();
  /*选中*/
  const [selectedRowsState, setSelectedRows] = useState();
  const [pwdVisible, setpwdVisible] = useState(false);
  const [roleVisible, setroleVisible] = useState(false);
  const [selectDatas, SetselectData] = useState();
  const [sysUserId, SetSysUserId] = useState();

  const InitRole = (id) => {
    SetSysUserId(id);
    api.GetRoleDic().then(r => {
      var arr = [];
      for (var key in r.data) {
        arr.push(<Option value={key}>{r.data[key]}</Option>)
      }
      SetselectData(arr);
      api.GetUserRole(id).then(r => {
        setStepFormValues(r.data);
        setroleVisible(true);
      });

    })
  }
  const Btn = (record) => {
    var arr = [];
    arr.push(<a
      disabled={record.adminType == 2}
      style={{ pointerEvents: record.adminType == 2 ? 'none' : 'auto' }}
      onClick={() => {
        handleModalVisible(true);
        setStepFormValues(record);
      }}
    >
      修改
    </a>);
    if (record.status == 1) {
      arr.push(<a
        disabled={record.adminType == 2}
        style={{ pointerEvents: record.adminType == 2 ? 'none' : 'auto' }}
        onClick={() => {
          api.Enable(record.id).then(r => {
            actionRef.current.reload();
          })
        }}
      >
        启用
      </a>);
    }
    if (record.status == 0) {
      arr.push(<a
        disabled={record.adminType == 2}
        style={{ pointerEvents: record.adminType == 2 ? 'none' : 'auto' }}
        onClick={() => {
          api.Disable(record.id).then(r => {
            actionRef.current.reload();
          })
        }}
      >
        禁用
      </a>);
    }
    arr.push(<a
      disabled={record.adminType == 2}
      style={{ pointerEvents: record.adminType == 2 ? 'none' : 'auto' }}
      onClick={() => {
        api.RemoveUser([record.id]).then(r => {
          r.data ? message.success("删除成功") : message.error("删除失败");
          actionRef.current.reload();
        })
      }}
    >
      删除
    </a>);
    arr.push(<a
      onClick={() => {
        api.ResetPwd(record.id).then(r => {
          r.data ? message.success("重置成功") : message.error("重置失败");
        })
      }}
    >
      重置密码
    </a>);
    arr.push(<a
      onClick={() => {
        setpwdVisible(true);

      }}
    >
      修改密码
    </a>);
    arr.push(<a
      disabled={record.adminType == 2}
      style={{ pointerEvents: record.adminType == 2 ? 'none' : 'auto' }}
      onClick={() => {
        InitRole(record.id);
      }}
    >
      角色授权
    </a>);
    arr.push(<a
      disabled={record.adminType == 2}
      style={{ pointerEvents: record.adminType == 2 ? 'none' : 'auto' }}
      onClick={() => {
        handleUpdateOrgModalVisible(true);
        setStepFormValues(record);
      }}
    >
      数据授权
    </a>);

    return arr;
  }

  /** 国际化配置 */
  const columns = [
    {
      title: '主键',
      dataIndex: 'id',
      tip: 'key',
      hideInSearch: true,
      hideInTable: true,
    },
    {
      title: '用户姓名',
      dataIndex: 'name',
    },
    {
      title: '登录账户',
      dataIndex: 'account'
    },
    {
      title: '账户类型',
      dataIndex: 'adminType',
      hideInSearch: true,
      valueEnum: {
        0: {
          text: '无',
          status: 'Default',
        },
        1: {
          text: '超级管理员',
          status: 'Processing',
        },
        2: {
          text: '管理员',
          status: 'Success',
        },
        3: {
          text: '普通账号',
          status: 'Default',
        },
      },
    },
    {
      title: '状态',
      dataIndex: 'status',
      hideInSearch: true,
      valueEnum: {
        0: {
          text: '启用',
          status: 'Processing',
        },
        1: {
          text: '禁用',
          status: 'Success',
        },
      },
    },
    {
      title: '是否删除',
      dataIndex: 'isDeleted',
      hideInSearch: true,
      valueEnum: {
        0: {
          text: '正常',
          status: 'Processing',
        },
        1: {
          text: '删除',
          status: 'Success',
        },
      },
    },

    {
      title: '创建时间',
      dataIndex: 'createAt',
      hideInSearch: true,
      sorter: true,
    },
    {
      title: '操作',
      dataIndex: 'option',
      valueType: 'option',
      render: (_, record) => Btn(record)
    },
  ];
  return (
    <PageContainer>
      <ProTable
        headerTitle="用户信息"
        actionRef={actionRef}
        rowKey="id"
        search={{
          labelWidth: 120,
        }}
        toolBarRender={() => {
          return <Button
            type="primary"
            key="create"
            onClick={() => {
              handleModalVisible(true);
            }}
          >
            <PlusOutlined /> 新建
          </Button>
        }}
        request={async (params) => {
          let UserData = [];
          var total = 0;
          await api.Page(params).then((r) => {
            UserData = r.data.data;
            total = r.data.total;
          });
          return {
            data: UserData,
            success: true,
            total: total,
          };
        }}
        columns={columns}
        rowSelection={{
          onChange: (_, selectedRows) => {
            setSelectedRows(selectedRows);
          },
        }}
      />
      {selectedRowsState?.length > 0 && (
        <FooterToolbar
          extra={
            <div>
              已选择{' '}
              <a
                style={{
                  fontWeight: 600,
                }}
              >
                {selectedRowsState.length}
              </a>{' '}
              项 &nbsp;&nbsp;
            </div>
          }
        >
          {/* {(Enumerable.from(localStorage.getItem("permissions").split(',')).contains(Prefix + "Delete") || localStorage.getItem("adminType") == 1) ? (<Button
                        type="primary"
                        onClick={async () => {
                            await handleRemove(selectedRowsState);
                            setSelectedRows([]);
                            actionRef.current?.reloadAndRest?.();
                        }}
                    >
                        批量删除
                    </Button>) : ''} */}
        </FooterToolbar>
      )}
      <CreateForm
        onFinish={async (value) => {
          var success = false;
          if (value.id) {
            success = await handleUpdate(value);
          } else {
            success = await handleAdd(value);
          }
          if (success) {
            handleModalVisible(false);
            setStepFormValues({});

            if (actionRef.current) {
              actionRef.current.reload();
            }
          }
          actionRef.current.reload();
        }}
        onCancel={() => {
          handleModalVisible(false);
          setStepFormValues({});
        }}
        modalVisible={createModalVisible}
        values={stepFormValues || {}}
      />

      <PwdForm
        onFinish={(value) => {
          api.UpdatePwd(value).then(r => {
            r.data ? message.success("修改成功") : message.error("修改失败");
            setpwdVisible(false);
          })
        }}
        onCancel={() => {
          setpwdVisible(false);
        }}
        pwdVisible={pwdVisible}
      />
      <RoleForm
        onFinish={(value) => {
          if (value.id) {
            api.UpdateUserRole(value).then(r => {
              r.data ? message.success("修改成功") : message.error("修改失败");
              setroleVisible(false);
            })
          } else {
            value.sysUserId = sysUserId;
            api.AddUserRole(value).then(r => {
              r.data ? message.success("添加成功") : message.error("添加失败");
              setroleVisible(false);
            })
          }

        }}
        selectData={selectDatas}
        values={stepFormValues}
        onCancel={() => {
          setStepFormValues({});
          setroleVisible(false);
        }}
        roleVisible={roleVisible}
      />
      {stepFormValues && Object.keys(stepFormValues).length ? (
        <OrgForm
          onFinish={async (value) => {
            const values = {
              sysUserId: stepFormValues.id,
              sysOrgId: value.orgId,
            };
            const success = await handleGrantData(values);
            if (success) {
              handleUpdateOrgModalVisible(false);
              setStepFormValues({});
              if (actionRef.current) {
                actionRef.current.reload();
              }
            }
          }}
          onCancel={() => {
            handleUpdateOrgModalVisible(false);
            setStepFormValues({});
          }}
          updateModalVisible={updateOrgModalVisible}
          values={stepFormValues}
        />
      ) : null}
    </PageContainer>
  );
};

export default userManager;
